.tdbmd-slide-panel {
    display: none;
    position: fixed;
    width: 100vw;
    top: 0;
    right: 0;
    transform: translateX(110%);
    z-index: 1000;
    box-sizing: border-box;
    transition: transform ease-in-out 0.3s;
}

.tdbmd-slide-panel .fr-accordion,
.tdbmd-slide-panel h2,
.tdbmd-slide-panel p,
.tdbmd-slide-panel ul {
    margin-left: 2rem;
    margin-right: 2rem;
}

.tdbmd-slide-panel .tdbmd-combobox-suggestions {
    max-height: 200px;
    overflow-y: scroll;
    width: 100%;
    margin: 0;
    padding: 0;
    list-style-type: none;
    box-sizing: border-box;
    margin-bottom: 2rem;
    margin-top: 2px;
}

.tdbmd-slide-panel .tdbmd-combobox-suggestions--opened {
    border-bottom: 2px solid var(--background-action-high-blue-france);
    border-left: 2px solid var(--background-action-high-blue-france);
    border-right: 2px solid var(--background-action-high-blue-france);
}

.tdbmd-slide-panel .tdbmd-slide-panel__title {
    color: var(--text-action-high-blue-france);
    padding-top: 1rem !important;
}

.tdbmd-slide-panel .tdbmd-territory-tabs .autocomplete-input {
    margin-bottom: 0;
}

.tdbmd-slide-panel .tdbmd-territory-tabs h2 {
    margin-left: 0;
}

.tdbmd-slide-panel.tdbmd-slide-panel--show {
    transform: initial;
}

@media (min-width: 992px) {
    .tdbmd-slide-panel {
        width: 60vw;
        right: 0;
        left: initial;
    }
    .tdbmd-slide-panel__btn {
        display: block !important;
        position: absolute;
        left: 0;
        transform: translateX(calc(-50% + 0.5rem));
    }
    .tdbmd-slide-panel__btn--mobile {
        display: none !important;
    }
    .tdbmd-slide-panel__content {
        margin-left: 2rem;
        border: 1px solid var(--border-default-grey);
    }
}
@media (min-width: 1248px) {
    .tdbmd-slide-panel {
        width: 50vw;
    }
}
.tdbmd-slide-panel__btn--mobile {
    display: block;
}
.tdbmd-slide-panel__btn.fr-btn.fr-btn--tertiary {
    display: none;
    box-sizing: border-box;
    padding: 0 0.8rem 0.4rem;
    border: none;
    background: white;
    color: var(--text-action-high-blue-france);
}

.tdbmd-slide-panel__content {
    height: 100vh;
    background: white;
    overflow: scroll;
    /* Hide scrollbar for Chrome, Safari and Opera */
    /* Hide scrollbar for IE, Edge and Firefox */
    -ms-overflow-style: none;
    /* IE and Edge */
    scrollbar-width: none;
    /* Firefox */
}

.tdbmd-slide-panel__content::-webkit-scrollbar {
    display: none;
}
.tdbmd-slide-panel__icon:before {
    transform: scaleX(-1);
}
