# Generated by Django 5.2.3 on 2025-06-19 12:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('indicators_lib', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='filter',
            name='color',
            field=models.TextField(blank=True, help_text='format hexadécimale : #FF11DD', null=True, verbose_name='Couleur'),
        ),
        migrations.AddField(
            model_name='indicator',
            name='min_mesh',
            field=models.TextField(choices=[('fr', 'National'), ('reg', 'Region'), ('dep', 'Department'), ('epci', 'Epci'), ('com', 'Town')], default='com'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='show_evolution',
            field=models.BooleanField(default=True),
        ),
    ]
