{% if filters|length > 1 %}
    <div class="filters-reminder">
        {% for dimension_filters in filters %}
            {% if not dimension_filters.0.is_breakdown %}
                <div>
                    <label>{{ dimension_filters.0.title }} : </label>
                    <span class="filters-reminder-dimension" data-dimension="{{ dimension_filters.0.db_name }}">
                        {% for filter in dimension_filters.1 %}
                            {% if filter.current %}
                            <p class="fr-tag">{{filter.db_name}}</p>
                            {% endif %}
                        {% endfor %}
                    </span>
                    <a class="fr-link fr-icon-arrow-up-line fr-link--icon-right fr-link--sm" href="#filtres">Modifier les filtres</a>
                </div>
            {% endif %}
        {% endfor %}
    </div>
{% endif %}
