{% extends "territories_dashboard_lib/website/layout/base.html" %}

{% load static %}

{% block page_title %}Accueil - {{ main_conf.title }}{% endblock %}

{% block main %}

<main role="main" id="contenu" tabindex="-1" class="fr-container fr-pt-10w fr-pb-10w">
    <h1>{{ landing_page.title }}</h1>
    {{ landing_page.body_html|safe }}
    <a class="fr-btn" href="{{ landing_page.button.href }}">{{ landing_page.button.title }}</a>
</main>
{% endblock %}
