# Generated by Django 5.1.6 on 2025-06-30 12:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracking_lib', '0002_alter_event_created_at_alter_page_created_at'),
    ]

    operations = [
        migrations.CreateModel(
            name='CookieInfo',
            fields=[
                ('id', models.TextField(primary_key=True, serialize=False)),
                ('country', models.TextField(blank=True, null=True)),
            ],
        ),
    ]
