#tdbmd-map {
    width: 100%;
    height: 60vh;
    position: relative;
    border: 1px solid var(--border-default-grey);
}
#tdbmd-map[fullscreen] {
    width: calc(100vw - 4rem);
    height: 90vh;
}
#tdbmd-map-legend {
    position: absolute;
    bottom: 10px;
    left: 10px;
    padding: 8px 16px 0px 16px;
    max-width: 300px;
    min-width: 200px;
    background-color: white;
    border-radius: 8px;
    opacity: 94%;
}
#tdbmd-map-legend .title {
    margin-bottom: 8px;
    font-size: 0.7rem;
    font-weight: bold;
    line-height: 1.3;
}
#tdbmd-map-legend .indicator-scale {
    width: 100%;
    height: 20px;
    opacity: 80%;
}
#tdbmd-map-legend .indicator-scale-values {
    width: 100%;
    display: flex;
    justify-content: space-between;
    gap: 8px;
}
#tdbmd-map-legend .scale-minmax {
    max-width: 100px;
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap;
    font-size: 0.7rem;
}
#map-sidebar {
    position: absolute;
    z-index: 2;
    right: -1px;
    width: 300px;
    height: 100%;
    transition: width ease-in-out 0.3s;
    border-left: 1px solid var(--border-default-grey);
    border-right: 1px solid var(--border-default-grey);
    background-color: white;
    opacity: 94%;
}
#map-sidebar .ms-container {
    width: 100%;
    height: 100%;
    overflow-x: hidden;
    overflow-y: scroll;
}
#map-sidebar .ms-body {
    width: 300px;
    height: 100%;
    padding: 16px;
    display: flex;
    flex-direction: column;
    gap: 32px;
}
#map-sidebar .sidebar-title {
    font-size: 1.2rem;
    font-weight: bold;
}
#map-sidebar .title {
    margin-bottom: 16px;
    font-size: 1rem;
    font-weight: bold;
}
#map-sidebar .territory-name {
    font-size: 0.8rem;
    font-style: italic;
}
#map-sidebar #collapse {
    position: absolute;
    left: -40px;
    top: 16px;
    width: 40px;
    height: 40px;
    background-color: white;
    color: var(--text-action-high-blue-france);
    border: 1px solid var(--border-default-grey);
    cursor: pointer;
}
#map-sidebar #collapse span:before {
    transform: scaleX(-1);
}
#map-sidebar #collapse:hover {
    background-color: var(--grey-1000-50-hover);
}
#map-sidebar #collapse:focus {
    outline-offset: 2px;
    outline: 2px solid #fcc63a;
    background-color: #fef5e8;
    border: 1px dashed gray;
}
#map-sidebar .loader {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 16px;
}
#map-sidebar .spinner {
    color: #465f9d;
    animation: spin 1s linear infinite;
}
#map-sidebar .spinner circle {
    stroke-dasharray: 100;
    stroke-dashoffset: 0;
}
@keyframes spin {
    100% {
        transform: rotate(360deg);
    }
}
#map-sidebar .geo-feature-count {
    display: flex;
    gap: 8px;
    align-items: center;
}
#map-sidebar .filterTitle {
    font-size: 13px;
    padding-left: 14px;
    margin-top: 4px;
    margin-bottom: 16px;
}
#map-sidebar[data-open="false"] {
    width: 32px;
}
#map-sidebar[data-open="false"] #collapse span:before {
    transform: scaleX(1);
}

#map-buttons {
    position: absolute;
    z-index: 1;
    top: 8px;
    left: 8px;
    display: flex;
    flex-direction: column;
    gap: 8px;
}
#map-buttons .map-button {
    border: 1px solid var(--border-default-grey);
    background-color: white;
    color: var(--text-action-high-blue-france);
    opacity: 94%;
    width: 32px;
    height: 32px;
    cursor: pointer;
    display: flex;
    justify-content: center;
    align-items: center;
}
#map-buttons .map-button:hover {
    background-color: var(--grey-1000-50-hover);
}
#map-buttons .map-button:focus {
    outline-offset: 2px;
    outline: 2px solid #fcc63a;
    background-color: #fef5e8;
    border: 1px dashed gray;
}
#map-download-buttons {
    margin-top: 32px;
    display: flex;
    flex-wrap: wrap;
    gap: 16px;
}
.mapboxgl-ctrl-logo {
    display: none !important;
}
#deckgl-wrapper:focus {
    outline: 2px solid #0a76f6 !important;
}
.table-geo-filters {
    margin-top: 16px;
    display: flex;
    flex-direction: column;
    gap: 8px;
    padding-bottom: 64px;
}

.table-geo-filters {
    font-size: 0.9rem;
}

.table-geo-filters:has(details[open]) {
    padding-bottom: 300px;
}

.table-geo-filters input,
.table-geo-filters select {
    padding: 4px 8px;
    max-width: 250px;
    margin-top: 0px !important;
}

.table-geo-filters input[type="number"] {
    max-width: 70px;
}

.table-geo-filters label,
.table-geo-filters i {
    font-size: 0.8rem;
}

.table-geo-filters-details-body {
    margin-top: 8px;
    margin-bottom: 8px;
}
.geo-filters-numbers-col {
    display: flex;
    flex-direction: column;
    gap: 8px;
}

.geo-filters-numbers-row {
    display: flex;
    flex-direction: row;
    gap: 32px;
}
.react-datepicker__input-container input {
    border-color: hsl(0, 0%, 80%);
    border-radius: 4px;
    border-style: solid;
    border-width: 1px;
    width: 95px;
}

.date-pickers-range {
    display: flex;
    flex-direction: row;
    gap: 32px;
}

.react-datepicker__header {
    background-color: #ececfe !important;
}

.react-datepicker__header h2 {
    padding: 0px !important;
}

.react-datepicker__header__dropdown {
    padding-bottom: 16px !important;
}

.react-datepicker__close-icon:hover {
    background-color: inherit !important;
}

.react-select__menu {
    font-size: 0.8rem !important;
}

.react-select__option {
    padding: 4px 12px !important;
}
