.tdbmd-slide-panel-fiche-methodo {
    overflow-y: scroll;
    height: 100vh;
}

.tdbmd-slide-panel-fiche-methodo .tdbmd-markdown .tdbmd-slide-panel__subtitle {
    margin-left: 0;
}

.tdbmd-slide-panel-fiche-methodo .tdbmd-markdown h3 {
    font-size: 1.4rem;
}

.tdbmd-slide-panel-fiche-methodo h3 {
    color: var(--text-default-grey);
    font-size: 1.2rem;
}

.tdbmd-slide-panel__subtitle {
    background: var(--background-action-high-blue-france);
    color: white !important;
    padding: 0.5rem 2rem;
    margin-top: 2rem !important;
    margin-bottom: 2rem !important;
}

.tdbmd-slide-panel__thematic {
    margin-left: 0px !important;
}
