{% extends "./side_panel.html" %}

{% block "type" %}methodo{% endblock %}

{% block "aria-label" %}Menu de la fiche méthodologique{% endblock %}

{% block "content" %}
<div id="slide-panel-content-methodo" class="tdbmd-slide-panel-fiche-methodo">
    <div class="fr-header">
        <div class="fr-header__body">
            <div class="fr-container">
                <div class="fr-header__body-row">
                    <div class="fr-header__brand">
                        <div class="fr-header__brand-top">
                            <div class="fr-header__logo">
                                    <p class="fr-logo">
                                        Ministères <br />
                                        aménagement <br />
                                        du territoire <br />
                                        transition <br/>
                                        écologique
                                    </p>
                            </div>
                        </div>
                        <div class="fr-header__service">
                            <p class="fr-header__service-title">
                                Tableau de bord des mobilités durables
                            </p>
                            <p class="fr-header__service-tagline">Fiche méthodologique</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <h1 class="fr-sr-only">Fiche méthodologique</h1>
    <h2 id="slide-panel-methodo-indicator-title" class="tdbmd-slide-panel__subtitle"></h2>
    <p class="tdbmd-slide-panel__thematic fr-pl-md-4w">Thématique : <span id="slide-panel-methodo-theme-title"></span></p>
    <div id="slide-panel-content-methodo-markdown" class="fr-pl-md-4w tdbmd-markdown"></div>
    <button id="methodo-export-button" class="fr-btn fr-btn--secondary fr-btn--sm fr-icon-file-pdf-line fr-btn--icon-right fr-mx-4w fr-mt-2w fr-mb-4w">Exporter la fiche méthodologique</button>
    <script>
        {% include "./side_panel_methodo.js" %}
    </script>
</div>
{% endblock %}
