<div class="fr-col-4 tdbmd-indicator-card__comparisons-col">
    <div class="tdbmd-indicator-card__comparisons-card fr-p-1w">
        <h5 class="tdbmd-indicator-card__comparisons-card-title">{{ title }}</h5>
        <p class="tdbmd-indicator-card__comparisons-card-number delay-spinner">
            <strong class="{{ prefix }}-value">
                <span>{% include "territories_dashboard_lib/website/pages/indicators/components/loader.html" with width=28 %}</span>
                <span class="unite" aria-label="{{indicator.unite_nom_accessible}}">{{indicator.unite}}</span>
            </strong>
        </p>
        <p class="tdbmd-indicator-card__comparisons-card-info" style="margin">
            <span class="{{ prefix }}-name"></span>
            <span class="{{ prefix }}-count"></span>
        </p>
    </div>
</div>
