.tdbmd-mesh {
    position: relative;
    width: 100%;
}

.tdbmd-mesh .tdbmd-mesh__btn {
    width: 100%;
    text-align: left;
    display: inline-block;
    border-bottom: 3px solid var(--text-action-high-blue-france);
    position: relative;
    background: white;
}

.tdbmd-mesh .tdbmd-mesh__btn-mesh {
    display: block;
}

.tdbmd-mesh .tdbmd-mesh__btn-title {
    display: block;
    color: var(--text-mention-grey);
}

.tdbmd-mesh .tdbmd-mesh__btn:after {
    position: absolute;
    top: 50%;
    right: 1rem;
    transform: translateY(-50%);
}

.tdbmd-mesh .tdbmd-mesh__list-btn {
    width: 100%;
    padding: 0 1rem;
    padding-right: 2.5rem;
}
@media (min-width: 575px) {
    .tdbmd-mesh {
        width: 200px;
    }
}
.tdbmd-mesh ul {
    position: absolute;
    z-index: 100;
    width: 100%;
}

.tdbmd-mesh__list {
    list-style-type: none;
    padding: 0;
    margin: 0;
    background: white;
    box-shadow: -1px 1px 5px 1px var(--border-default-grey);
}

.tdbmd-mesh__list .tdbmd-mesh__list-btn {
    color: var(--text-default-grey);
}

.tdbmd-mesh__list .tdbmd-mesh__list-btn--current {
    color: var(--text-action-high-blue-france);
}

.tdbmd-mesh__list-item {
    margin: 0;
    padding: 0;
}

.tdbmd-territory .tdbmd-territory__btn {
    width: 100%;
    text-align: left;
    display: inline-block;
    border-bottom: 3px solid var(--text-action-high-blue-france);
    position: relative;
    background: white;
    padding-right: 2.5rem;
}

.tdbmd-territory .tdbmd-territory__btn-mesh {
    display: block;
    white-space: nowrap;
}

.tdbmd-territory .tdbmd-territory__btn-title {
    display: block;
    color: var(--text-mention-grey);
    white-space: nowrap;
}

.tdbmd-territory .tdbmd-territory__btn:after {
    position: absolute;
    top: 50%;
    right: 1rem;
    transform: translateY(-50%);
}
