.filters-reminder {
    margin-top: 16px;
}

.filters-reminder a {
    margin-left: 8px;
}

.filters-reminder label {
    font-style: italic;
    font-size: smaller;
    margin-right: 8px;
}

.filters-reminder-dimension > p:not(:first-child) {
    margin-left: 4px;
}
