.tdbmd-indicator-card__comparisons-card {
    border: 1px solid var(--border-default-grey);
    border-left: 3px solid var(--background-action-high-blue-france);
    color: var(--text-action-high-blue-france);
    text-align: center;
    height: 100%;
}

.tdbmd-indicator-card__comparisons-card-info {
    cursor: pointer;
    margin-bottom: 1rem;
}

.tdbmd-indicator-card__comparisons-card-info span {
    display: block;
}

.tdbmd-indicator-card__comparisons-card-number {
    font-size: 1.5rem;
    margin-bottom: 1rem;
}

.tdbmd-indicator-card__comparisons-card-title {
    font-weight: 700;
    margin-bottom: 1rem;
    font-size: 1.2rem;
}

.tdbmd-indicator-card__comparisons-col {
    min-width: 150px;
}
.tdbmd-indicator-card__comparisons-card--average {
    border-left-color: var(--background-action-high-blue-france);
}
